#!/usr/bin/env python
# coding=utf-8
"""
@author: Jiawei Wu
@create time: 2019-12-06 23:23
@edit time: 2020-11-23 17:29
@FilePath: /vvlab/vvlab/models/__init__.py
"""


from .actor_net import SimpleActorNet
from .critic_net import SimpleCriticNet
from .dqn_net import SimpleDQNNet